@@ -43,7 +43,9 @@ __all__ = (
     "PlatformCapabilityType",
     "ResourceTypeType",
     "RetryActionType",
+    "BatchServiceName",
     "ServiceName",
+    "ResourceServiceName",
     "PaginatorName",
 )
 
@@ -73,6 +75,7 @@ LogDriverType = Literal["awslogs", "fluentd", "gelf", "journald", "json-file", "
 PlatformCapabilityType = Literal["EC2", "FARGATE"]
 ResourceTypeType = Literal["GPU", "MEMORY", "VCPU"]
 RetryActionType = Literal["EXIT", "RETRY"]
+BatchServiceName = Literal["batch"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -104,6 +107,7 @@ ServiceName = Literal[
     "backup",
     "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
@@ -226,6 +230,7 @@ ServiceName = Literal[
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -374,6 +379,18 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
 PaginatorName = Literal[
     "describe_compute_environments",
     "describe_job_definitions",
